// Helper routines for CSGTestC
//
#include <afxpriv.h>
#include "stdafx.h"
#include "CSGTestC.h"
#include "CSGTedlg.h"
#include "procs.h"

extern CCSGTestCApp theApp;

CString GetSpaceDelimitedToken(CString *ptr)
//********************************************************************
// This routine searches the parameter string for a space character.
// If found, it returns all characters to the left of the space,
// and removes these characters from the head of the parameter string.
// If no space is found, the entire parameter string is returned, and
// the parameter string is set to null.
// If the parameter string is empty, and empty string is returned.
//********************************************************************
   {
   int i;                   // Index of found space character
   CString ReturnValue;

   ReturnValue.Empty();     // Init to empty string

   ptr->TrimLeft();
   if (ptr->IsEmpty())
      // Empty string
      return ReturnValue;

   i = ptr->Find(' ');
   if (i < 0)
      {
      // Not found
      ReturnValue = *ptr;
      ptr->Empty();         // Set parameter string to Empty
      }
   else
      {
      // Found
      ReturnValue = ptr->Left(i);
      *ptr = ptr->Mid(i);
      }
   return ReturnValue;
   }  // GetSpaceDelimitedToken 
//********************************************************************

void SetVariantFromBstr(VARIANTARG *vptr, BSTR *bptr)
//********************************************************************
// This routine initializes the VARIANTARG parameter vptr, and sets
// it to contain the string given by bptr.
//********************************************************************
   {
   VariantInit(vptr);                    // Init structure
   vptr->vt = VT_BYREF|VT_BSTR;          // Param type is string passed by reference
   vptr->pbstrVal = bptr;                // Set string pointer in struct
   }  // SetVariantFromBstr
//********************************************************************

void SetReplyMemberVars(short Status, short Substatus, LPCTSTR ReplyData, long Option)
//********************************************************************
// This routine sets the reply member variables mReplyStatus, 
// mReplySubstatus, and mReceiveText to the passed values, then
// updates the main dialog box.  If the delay check box is checked,
// this routine will also display a modal message box. 
//********************************************************************
   {
   CCSGTestCDlg *Dlgptr;
   CString WhichProc;
   char StatusString[10];
   char SubstatusString[10];
   short i;
	 
   for(i = 0; i < 10; i++)
      {
      StatusString[i] = '\0';
      SubstatusString[i] = '\0';
      }

   Dlgptr = (CCSGTestCDlg *)theApp.m_pMainWnd;

   _itoa(Status, StatusString, 10);
   Dlgptr->mReplyStatusControl.SetSel(0, -1);
   Dlgptr->mReplyStatusControl.ReplaceSel(&StatusString[0]);  

   _itoa(Substatus, SubstatusString, 10);
   Dlgptr->mReplySubstatusControl.SetSel(0, -1);
   Dlgptr->mReplySubstatusControl.ReplaceSel(&SubstatusString[0]);  

   Dlgptr->mReceiveTextControl.SetSel(0, -1);           // Select all text
   Dlgptr->mReceiveTextControl.ReplaceSel(ReplyData);   // Replace it with current text
   Dlgptr->mReceiveTextControl.SetSel(0, 0);            // Position to first character in text box
   if (Dlgptr->mDelay)
      {
      // Delay check box is set; display message
	   switch(Option)
	      {
		   case optCSGSend:        WhichProc = "CSGReply";
		                           break;
		   case optSSGSend:        WhichProc = "SSGReply";
		                           break;
		   case optSSGSendPrivate: WhichProc = "SSGReplyPrivate";
		                           break;
         case optSSGSendShare:   WhichProc = "SSGReplyShare";
		                           break;
		   case optSSGSendStatus:  WhichProc = "SSGReplyStatus";
		                           break;
		   case optSSGSendListdev: WhichProc = "SSGReplyListdev";
		                           break;
		   case optSRVSend:        WhichProc = "SRVReply";
		                           break;
		   default:                WhichProc = "<Unknown>";
		   }
      MessageBox(Dlgptr->m_hWnd, "Delaying in reply procedure " + WhichProc, "Reply Delay", MB_ICONHAND|MB_OK);
      } 
      
   }  // SetReplyMemberVars
//********************************************************************

/*==========================================================================*
 *                        WaitForResource                                   *
 *==========================================================================*/
void WaitForResource(int *WaitVar, int WaitValue)
/****************************************************************************
 * This routine loops and calls GetMessage and DispatchMessage repeatedly   *
 * until the value of the wait state variable changes to the value given    *
 * by WaitValue.                                                             *
 ****************************************************************************/
   {
   MSG  msg;
   BOOL count;

   while (*WaitVar != WaitValue)
      {
      count = PeekMessage(&msg, NULL, 0, 0, PM_REMOVE);
      if (count != 0) 
         {
         TranslateMessage(&msg);
         DispatchMessage(&msg);
         }
      }
   } // WaitForResource routine */

// *** End of file procs.cpp ***
